@@ -22,7 +22,7 @@
 #define SETUP_SCREEN_DISABLE_SCREENSAVER_DEFAULT false
 #define SETUP_SCREEN_DIM_TIMEOUT "screen/dim_timeout"
 #define SETUP_SCREEN_DIM_TIMEOUT_DEFAULT 5
-#define SETUP_SCREEN_LOCK_TIMEOUT "screen/dim_timeout"
+#define SETUP_SCREEN_LOCK_TIMEOUT "screen/lock_timeout"
 #define SETUP_SCREEN_LOCK_TIMEOUT_DEFAULT 150
 #define SETUP_SCREEN_DIM_PERCENT "screen/dim_percent"
 #define SETUP_SCREEN_DIM_PERCENT_DEFAULT 20
